@@ -21,7 +21,8 @@ displayio.release_displays()
 # oled_reset = board.D9
 
 # Use for I2C
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 display_bus = displayio.I2CDisplay(i2c, device_address=0x3C)
 
 # SH1107 is vertically oriented 64x128
